@@ -24,12 +24,19 @@ DEFAULT_QUALITIES = [
     ('m7', (0, 3, 7, 10)),
     ('m7-5', (0, 3, 6, 10)),
     ('m7b5', (0, 3, 6, 10)),
-    ('dim6', (0, 3, 6, 9)),
+    ('m7+5', (0, 3, 8, 10)),
+    ('m7#5', (0, 3, 8, 10)),
+    ('dim6', (0, 3, 6, 8)),
+    ('dim7', (0, 3, 6, 9)),
     ('M7', (0, 4, 7, 11)),
     ('maj7', (0, 4, 7, 11)),
     ('M7+5', (0, 4, 8, 11)),
     ('mM7', (0, 3, 7, 11)),
+    ('add4', (0, 4, 5, 7)),
+    ('Madd4', (0, 4, 5, 7)),
+    ('madd4', (0, 3, 5, 7)),
     ('add9', (0, 4, 7, 14)),
+    ('Madd9', (0, 4, 7, 14)),
     ('madd9', (0, 3, 7, 14)),
     ('2', (0, 4, 7, 14)),
     ('add11', (0, 4, 7, 17)),
@@ -58,11 +65,16 @@ DEFAULT_QUALITIES = [
     ('11', (0, 7, 10, 14, 17)),
     ('7+11', (0, 4, 7, 10, 18)),
     ('7#11', (0, 4, 7, 10, 18)),
+    ('M7+11', (0, 4, 7, 11, 18)),
+    ('M7#11', (0, 4, 7, 11, 18)),
     ('7b9#9', (0, 4, 7, 10, 13, 15)),
     ('7b9#11', (0, 4, 7, 10, 13, 18)),
     ('7#9#11', (0, 4, 7, 10, 15, 18)),
     ('7-13', (0, 4, 7, 10, 20)),
     ('7b13', (0, 4, 7, 10, 20)),
+    ('m7add11', (0, 3, 7, 10, 17)),
+    ('M7add11', (0, 4, 7, 11, 17)),
+    ('mM7add11', (0, 3, 7, 11, 17)),
     # 6 notes
     ('7b9b13', (0, 4, 7, 10, 13, 17, 20)),
     ('9+11', (0, 4, 7, 10, 14, 18)),
@@ -74,4 +86,5 @@ DEFAULT_QUALITIES = [
     ('13#9', (0, 4, 7, 10, 15, 21)),
     ('13+11', (0, 4, 7, 10, 18, 21)),
     ('13#11', (0, 4, 7, 10, 18, 21)),
+    ('M7add13', (0, 4, 7, 9, 11, 14))
 ]
