@@ -27,6 +27,10 @@ class TestNotesToPositions(unittest.TestCase):
     def test_add9(self):
         pos = notes_to_positions(["Ab", "C", "Eb", "Bb"], "Ab")
         self.assertEqual(pos, [0, 4, 7, 14])
+    
+    def test_major_add_9(self):
+        # major add 9 is the same as add9
+        self.test_add9()
 
     def test_ninth(self):
         pos = notes_to_positions(["F", "A", "C", "Eb", "G"], "F")
@@ -53,7 +57,21 @@ class TestGetAllRotatedNotes(unittest.TestCase):
 
 
 class TestNoteToChord(unittest.TestCase):
-
+    def _assert_chords(self, notes, expected_chords):
+        """"Validates that the specified notes translated to the expected chords.
+        :param notes: The notes of the chord, either as a list of strings,
+          e.g. ["G", "C", "D"] or a string, e.g. "G C D"
+        :param expected_chords: the chords that the notes could translate to, 
+            specified as a list of strings, e.g. [ "Gsus4", "Csus2/G" ], 
+            or a single string if only one chord expected.
+        """
+        if isinstance(notes, str):
+            notes = notes.split()
+        c0 = note_to_chord(notes)
+        if isinstance(expected_chords, str):
+            expected_chords = [expected_chords]
+        self.assertEqual(c0, [Chord(c) for c in expected_chords])
+    
     def test_major(self):
         chords = note_to_chord(["C", "E", "G"])
         self.assertEqual(chords, [Chord("C")])
@@ -76,7 +94,7 @@ class TestNoteToChord(unittest.TestCase):
 
     def test_dim6(self):
         chords = note_to_chord(["Eb", "Gb", "A", "C"])
-        self.assertEqual(chords, [Chord("Ebdim6"), Chord("Gbdim6/Eb"), Chord("Adim6/Eb"), Chord("Cdim6/Eb")])
+        self.assertEqual(chords, [Chord("Ebdim7"), Chord("Gbdim7/Eb"), Chord("Adim7/Eb"), Chord("Cdim7/Eb")])
 
     def test_aug(self):
         chords = note_to_chord(["F", "A", "Db"])
@@ -93,9 +111,30 @@ class TestNoteToChord(unittest.TestCase):
     def test_m7dim5(self):
         chords = note_to_chord(["F#", "A", "C", "E"])
         self.assertEqual(chords, [Chord("F#m7-5"), Chord("Am6/F#")])
+    
+    def test_add4(self):
+        chords = note_to_chord(["C", "E", "F", "G"])
+        self.assertEqual(chords, [Chord("Cadd4")])
+    
+    def test_minor_add4(self):
+        chords = note_to_chord(["C", "Eb", "F", "G"])
+        self.assertEqual(chords, [Chord("Cmadd4")])
+    
+    def test_minor7_add11(self):
+        self._assert_chords("C Eb G Bb F", ["Cm7add11", "F11/C"])
+    
+    def test_major7_add11(self):
+        self._assert_chords("C E G B F", "CM7add11")
+
+    def test_minormajor7_add11(self):
+        self._assert_chords("C Eb G B F", "CmM7add11")
+
+    def test_major7_add13(self):
+        self._assert_chords("C E G A B D", "CM7add13")
+
 
     def test_call_repeatedly(self):
         for _ in range(2):
             chords = note_to_chord(["Eb", "Gb", "A", "C"])
-            self.assertEqual(chords, [Chord("Ebdim6"), Chord("Gbdim6/Eb"), Chord("Adim6/Eb"), Chord("Cdim6/Eb")])
+            self.assertEqual(chords, [Chord("Ebdim7"), Chord("Gbdim7/Eb"), Chord("Adim7/Eb"), Chord("Cdim7/Eb")])
             self.assertEqual(chords[0].components(visible=True), ["Eb", "Gb", "A", "C"])
